@@ -1,7 +1,10 @@
 from .image import Image, imageFragment
 from .program_invitation import ProgramInvitation
 from .program_module import ProgramModule
-from .program_track_action_response import ProgramTrackActionResponse, programTrackActionResponseFragment
+from .program_track_action_response import (
+    ProgramTrackActionResponse,
+    programTrackActionResponseFragment,
+)
 from .program_track_action import ProgramTrackAction, programTrackActionFragment
 from .program import Program
 from .session import Session
