@@ -1,10 +1,10 @@
 from obschart.api.node import Node
 
-programInvitationFragment = '''
+programInvitationFragment = """
 fragment ProgramInvitation on ProgramInvitation {
     id
 }
-'''
+"""
 
 
 class ProgramInvitation(Node):
