@@ -1,3 +1,4 @@
+from typing import Any
 from ..node import Node
 from .program_track_action import ProgramTrackAction, programTrackActionFragment
 from gql import gql
@@ -30,23 +31,32 @@ class ProgramTrackActionResponse(Node):
     def response(self):
         return self._data["response"]
 
-    def set_feedback_with_data(self, data_json):
+    def __set_feedback(self, data, wait_for_feedback=True):
+        if not self.action.waits_for_feedback:
+            raise RuntimeError(
+                "Can't set feedback for this response because its action does not wait for feedback."
+            )
+
+        pta = self._context.client.create_program_track_action(data, wait_for_feedback)
+
+        self._context.client.update_program_track_action_response(self.id, pta.id)
+
+        return pta
+
+    def set_feedback_with_data(self, data_json: str, wait_for_feedback=True) -> ProgramTrackAction:
         data = json.loads(data_json.replace("\n", "\\n"))
 
-        pta = self._context.client.create_program_track_action(data)
+        return self.__set_feedback(data, wait_for_feedback)
 
-        self._context.client.update_program_track_action_response(self.id, pta.id)
-
-        return pta
-
-    def set_feedback(self, title: str, blocks):
+    def set_feedback(self, title: str, blocks_action, wait_for_feedback=True) -> ProgramTrackAction:
         data = {
             "type": "multiStep",
-            "steps": [{"name": title, "action": {"type": "blocks", "blocks": blocks}}],
+            "steps": [{"name": title, "action": blocks_action}],
         }
 
-        pta = self._context.client.create_program_track_action(data)
+        return self.__set_feedback(data, wait_for_feedback)
 
-        self._context.client.update_program_track_action_response(self.id, pta.id)
+    def set_no_feedback(self):
+        data = {"type": "multiStep", "steps": []}
 
-        return pta
+        self.__set_feedback(data, False)
